This folder contain the game graphics. All the graphics file has been modified by hand from the original files that was grabbed from: https://www.spriters-resource.com/nes/supermariobros/. Except for the font.gif file as it is the same as file from the MarioAI framework.